Package: AnnotationHubData
Type: Package
Title: Transform public data resources into Bioconductor Data
        Structures
Version: 1.42.0
Encoding: UTF-8
Authors@R: c(
	person("Martin", "Morgan", role="ctb"),
	person("Marc", "Carlson", role="ctb"),
	person("Dan", "Tenenbaum", role="ctb"),
	person("Sonali", "Arora", role="ctb"),
	person("Paul", "Shannon", role="ctb"),
	person("Lori", "Shepherd", role="ctb"),
	person("Bioconductor Package Maintainer",
	    email="maintainer@bioconductor.org", role="cre")
	)
Depends: R (>= 3.2.2), methods, utils, S4Vectors (>= 0.7.21), IRanges
        (>= 2.3.23), GenomicRanges, AnnotationHub (>= 2.15.15)
Suggests: RUnit, knitr, BiocStyle, grasp2db, GenomeInfoDbData,
        rmarkdown, HubPub
Imports: GenomicFeatures, Rsamtools, rtracklayer, BiocGenerics,
        jsonlite, BiocManager, biocViews, BiocCheck, graph,
        AnnotationDbi, Biobase, Biostrings, DBI, Seqinfo, GenomeInfoDb
        (>= 1.45.5), OrganismDbi, RSQLite, AnnotationForge,
        futile.logger (>= 1.3.0), XML, RCurl
Description: These recipes convert a wide variety and a growing number of
    public bioinformatic data sets into easily-used standard Bioconductor data
    structures.
License: Artistic-2.0
LazyLoad: yes
biocViews: DataImport
VignetteBuilder: knitr
Collate: Message-class.R ImportPreparer-class.R
        makeAnnotationHubResource.R HubMetadata-class.R
        AnnotationHubMetadata-class.R utils.R updateResources.R
        ahmToJson.R webAccessFunctions.R makeChEA.R makedbSNPVCF.R
        makeEncodeDCC.R makeEnsemblGtfToGRanges.R makeEnsemblFasta.R
        makeEpigenomeRoadmap.R makeGencodeFasta.R makeGencodeGFF.R
        makeGrasp2Db.R makeHaemCode.R makeInparanoid8ToDbs.R
        makeNCBIToOrgDbs.R makeStandardOrgDbsToSqlite.R
        makeStandardTxDbsToSqlite.R makeRefNet.R makeUCSCChain.R
        makeUCSC2Bit.R makeUCSCTracks.R
        trackWithAuxiliaryTableToGRangesRecipe.R
        UCSCTrackUpdateChecker.R makeEnsemblTwoBit.R
        validationFunctions.R
git_url: https://git.bioconductor.org/packages/AnnotationHubData
git_branch: RELEASE_3_23
git_last_commit: 731b98b
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-06-02
NeedsCompilation: no
Packaged: 2026-06-02 16:20:24 UTC; biocbuild
Author: Martin Morgan [ctb],
  Marc Carlson [ctb],
  Dan Tenenbaum [ctb],
  Sonali Arora [ctb],
  Paul Shannon [ctb],
  Lori Shepherd [ctb],
  Bioconductor Package Maintainer [cre]
Maintainer: Bioconductor Package Maintainer <maintainer@bioconductor.org>
Built: R 4.6.0; ; 2026-06-03 13:07:46 UTC; unix
